@@ -16,10 +16,21 @@ instead.
 humanfriendly :
     spyder-terminal plugin
     ModuleNotFoundError: No module named 'humanfriendly.tables'
+keyring:
+    ModuleNotFoundError: No module named 'keyring.backends.kwallet'
+    ModuleNotFoundError: No module named 'keyring.backends.SecretService'
+    ModuleNotFoundError: No module named 'keyring.backends.Windows'
+    ModuleNotFoundError: No module named 'keyring.backends.chainer'
+    ModuleNotFoundError: No module named 'keyring.backends.libsecret'
+    ModuleNotFoundError: No module named 'keyring.backends.macOS'
 pkg_resources:
     ImportError: The 'more_itertools' package is required; normally this is
     bundled with this package so if you get this warning, consult the
     packager of your distribution.
+pygments:
+    ModuleNotFoundError: No module named 'pygments.formatters.latex'
+pylint_venv:
+    Mandatory: pylint_venv >=2.1.1 : None (NOK)
 pyls_spyder :
     Mandatory: pyls_spyder >=0.1.1 : None (NOK)
 pylsp_black :
@@ -38,7 +49,10 @@ spyder_terminal :
 # Packages that cannot be in the zip folder
 PACKAGES = [
     'humanfriendly',
+    'keyring',
     'pkg_resources',
+    'pygments',
+    'pylint_venv',
     'pyls_spyder',
     'pylsp_black',
     'setuptools',
