@@ -20,6 +20,7 @@ Licensed under the terms of the MIT License
 # Stdlib imports
 # =============================================================================
 from collections import OrderedDict
+import configparser as cp
 from enum import Enum
 import errno
 import gc
@@ -37,7 +38,6 @@ import traceback
 # Check requirements before proceeding
 #==============================================================================
 from spyder import requirements
-requirements.check_path()
 requirements.check_qt()
 
 #==============================================================================
@@ -82,7 +82,7 @@ from spyder.config.main import OPEN_FILES_PORT
 from spyder.config.manager import CONF
 from spyder.config.utils import IMPORT_EXT, is_gtk_desktop
 from spyder.otherplugins import get_spyderplugins_mods
-from spyder.py3compat import configparser as cp, PY3, to_text_string
+from spyder.py3compat import to_text_string
 from spyder.utils import encoding, programs
 from spyder.utils.icon_manager import ima
 from spyder.utils.misc import (select_port, getcwd_or_home,
@@ -131,8 +131,6 @@ class MainWindow(QMainWindow, SpyderConfigurationAccessor):
         QMainWindow.AllowTabbedDocks | QMainWindow.AllowNestedDocks |
         QMainWindow.AnimatedDocks
     )
-    SPYDER_PATH = get_conf_path('path')
-    SPYDER_NOT_ACTIVE_PATH = get_conf_path('not_active_path')
     DEFAULT_LAYOUTS = 4
     INITIAL_CWD = getcwd_or_home()
 
@@ -140,13 +138,25 @@ class MainWindow(QMainWindow, SpyderConfigurationAccessor):
     restore_scrollbar_position = Signal()
     sig_setup_finished = Signal()
     all_actions_defined = Signal()
-    # type: (OrderedDict, OrderedDict)
-    sig_pythonpath_changed = Signal(object, object)
     sig_open_external_file = Signal(str)
     sig_resized = Signal("QResizeEvent")
     sig_moved = Signal("QMoveEvent")
     sig_layout_setup_ready = Signal(object)  # Related to default layouts
 
+    # To be removed in Spyder 6
+    sig_pythonpath_changed = Signal(object, object)
+
+    sig_window_state_changed = Signal(object)
+    """
+    This signal is emitted when the window state has changed (for instance,
+    between maximized and minimized states).
+
+    Parameters
+    ----------
+    window_state: Qt.WindowStates
+        The window state.
+    """
+
     def __init__(self, splash=None, options=None):
         QMainWindow.__init__(self)
         qapp = QApplication.instance()
@@ -199,12 +209,6 @@ class MainWindow(QMainWindow, SpyderConfigurationAccessor):
         self.shortcut_data = []
         self.shortcut_queue = []
 
-        # Handle Spyder path
-        self.path = ()
-        self.not_active_path = ()
-        self.project_path = ()
-        self._path_manager = None
-
         # New API
         self._APPLICATION_TOOLBARS = OrderedDict()
         self._STATUS_WIDGETS = OrderedDict()
@@ -253,8 +257,6 @@ class MainWindow(QMainWindow, SpyderConfigurationAccessor):
         self.debug_menu_actions = []
 
         # TODO: Move to corresponding Plugins
-        self.main_toolbar = None
-        self.main_toolbar_actions = []
         self.file_toolbar = None
         self.file_toolbar_actions = []
         self.run_toolbar = None
@@ -432,6 +434,8 @@ class MainWindow(QMainWindow, SpyderConfigurationAccessor):
         # Connect Main window Signals to plugin signals
         self.sig_moved.connect(plugin.sig_mainwindow_moved)
         self.sig_resized.connect(plugin.sig_mainwindow_resized)
+        self.sig_window_state_changed.connect(
+            plugin.sig_mainwindow_state_changed)
 
         # Register plugin
         plugin._register(omit_conf=omit_conf)
@@ -468,13 +472,8 @@ class MainWindow(QMainWindow, SpyderConfigurationAccessor):
             try:
                 context = '_'
                 name = 'switch to {}'.format(plugin.CONF_SECTION)
-                shortcut = self.get_shortcut(
-                    name,
-                    context,
-                    plugin_name=plugin.CONF_SECTION
-                )
             except (cp.NoSectionError, cp.NoOptionError):
-                shortcut = None
+                pass
 
             sc = QShortcut(QKeySequence(), self,
                            lambda: self.switch_to_plugin(plugin))
@@ -675,9 +674,6 @@ class MainWindow(QMainWindow, SpyderConfigurationAccessor):
         # and remove this import. Help plugin should take care of it
         from spyder.plugins.help.utils.sphinxify import CSS_PATH, DARK_CSS_PATH
         logger.info("*** Start of MainWindow setup ***")
-        logger.info("Updating PYTHONPATH")
-        path_dict = self.get_spyder_pythonpath_dict()
-        self.update_python_path(path_dict)
 
         logger.info("Applying theme configuration...")
         ui_theme = self.get_conf('ui_theme', section='appearance')
@@ -778,6 +774,10 @@ class MainWindow(QMainWindow, SpyderConfigurationAccessor):
                     PLUGIN_REGISTRY.register_plugin(self, PluginClass,
                                                     external=False)
 
+        # To be removed in Spyder 6
+        ppm = self.get_plugin(Plugins.PythonpathManager)
+        ppm.sig_pythonpath_changed.connect(self.sig_pythonpath_changed)
+
         # Instantiate internal Spyder 4 plugins
         for plugin_name in internal_plugins:
             if plugin_name in enabled_plugins:
@@ -835,7 +835,7 @@ class MainWindow(QMainWindow, SpyderConfigurationAccessor):
         # TODO: Remove when all menus are migrated to use the Main Menu Plugin
         logger.info("Creating Menus...")
         from spyder.plugins.mainmenu.api import (
-            ApplicationMenus, ToolsMenuSections, FileMenuSections)
+            ApplicationMenus, FileMenuSections)
         mainmenu = self.mainmenu
         self.edit_menu = mainmenu.get_application_menu("edit_menu")
         self.search_menu = mainmenu.get_application_menu("search_menu")
@@ -846,28 +846,30 @@ class MainWindow(QMainWindow, SpyderConfigurationAccessor):
 
         # Switcher shortcuts
         self.file_switcher_action = create_action(
-                                    self,
-                                    _('File switcher...'),
-                                    icon=ima.icon('filelist'),
-                                    tip=_('Fast switch between files'),
-                                    triggered=self.open_switcher,
-                                    context=Qt.ApplicationShortcut,
-                                    id_='file_switcher')
+            self,
+            _('File switcher...'),
+            icon=ima.icon('filelist'),
+            tip=_('Fast switch between files'),
+            triggered=self.open_switcher,
+            context=Qt.ApplicationShortcut,
+            id_='file_switcher'
+        )
         self.register_shortcut(self.file_switcher_action, context="_",
                                name="File switcher")
         self.symbol_finder_action = create_action(
-                                    self, _('Symbol finder...'),
-                                    icon=ima.icon('symbol_find'),
-                                    tip=_('Fast symbol search in file'),
-                                    triggered=self.open_symbolfinder,
-                                    context=Qt.ApplicationShortcut,
-                                    id_='symbol_finder')
+            self, _('Symbol finder...'),
+            icon=ima.icon('symbol_find'),
+            tip=_('Fast symbol search in file'),
+            triggered=self.open_symbolfinder,
+            context=Qt.ApplicationShortcut,
+            id_='symbol_finder'
+        )
         self.register_shortcut(self.symbol_finder_action, context="_",
                                name="symbol finder", add_shortcut_to_tip=True)
 
         def create_edit_action(text, tr_text, icon):
             textseq = text.split(' ')
-            method_name = textseq[0].lower()+"".join(textseq[1:])
+            method_name = textseq[0].lower() + "".join(textseq[1:])
             action = create_action(self, tr_text,
                                    icon=icon,
                                    triggered=self.global_callback,
@@ -903,10 +905,11 @@ class MainWindow(QMainWindow, SpyderConfigurationAccessor):
         ]
         for switcher_action in switcher_actions:
             mainmenu.add_item_to_application_menu(
-                    switcher_action,
-                    menu_id=ApplicationMenus.File,
-                    section=FileMenuSections.Switcher,
-                    before_section=FileMenuSections.Restart)
+                switcher_action,
+                menu_id=ApplicationMenus.File,
+                section=FileMenuSections.Switcher,
+                before_section=FileMenuSections.Restart
+            )
         self.set_splash("")
 
         # Toolbars
@@ -916,40 +919,6 @@ class MainWindow(QMainWindow, SpyderConfigurationAccessor):
         self.file_toolbar = toolbar.get_application_toolbar("file_toolbar")
         self.run_toolbar = toolbar.get_application_toolbar("run_toolbar")
         self.debug_toolbar = toolbar.get_application_toolbar("debug_toolbar")
-        self.main_toolbar = toolbar.get_application_toolbar("main_toolbar")
-
-        # Tools + External Tools (some of this depends on the Application
-        # plugin)
-        logger.info("Creating Tools menu...")
-
-        spyder_path_action = create_action(
-            self,
-            _("PYTHONPATH manager"),
-            None, icon=ima.icon('pythonpath'),
-            triggered=self.show_path_manager,
-            tip=_("PYTHONPATH manager"),
-            id_='spyder_path_action')
-        from spyder.plugins.application.container import (
-            ApplicationActions, WinUserEnvDialog)
-        winenv_action = None
-        if WinUserEnvDialog:
-            winenv_action = ApplicationActions.SpyderWindowsEnvVariables
-        mainmenu.add_item_to_application_menu(
-            spyder_path_action,
-            menu_id=ApplicationMenus.Tools,
-            section=ToolsMenuSections.Tools,
-            before=winenv_action,
-            before_section=ToolsMenuSections.External
-        )
-
-        # Main toolbar
-        from spyder.plugins.toolbar.api import (
-            ApplicationToolbars, MainToolbarSections)
-        self.toolbar.add_item_to_application_toolbar(
-            spyder_path_action,
-            toolbar_id=ApplicationToolbars.Main,
-            section=MainToolbarSections.ApplicationSection
-        )
 
         self.set_splash(_("Setting up main window..."))
 
@@ -1330,7 +1299,7 @@ class MainWindow(QMainWindow, SpyderConfigurationAccessor):
     def update_edit_menu(self):
         """Update edit menu"""
         widget, textedit_properties = self.get_focus_widget_properties()
-        if textedit_properties is None: # widget is not an editor/console
+        if textedit_properties is None:  # widget is not an editor/console
             return
         # !!! Below this line, widget is expected to be a QPlainTextEdit
         #     instance
@@ -1349,10 +1318,10 @@ class MainWindow(QMainWindow, SpyderConfigurationAccessor):
         self.selectall_action.setEnabled(True)
 
         # Undo, redo
-        self.undo_action.setEnabled( readwrite_editor \
-                                     and widget.document().isUndoAvailable() )
-        self.redo_action.setEnabled( readwrite_editor \
-                                     and widget.document().isRedoAvailable() )
+        self.undo_action.setEnabled(readwrite_editor
+                                    and widget.document().isUndoAvailable())
+        self.redo_action.setEnabled(readwrite_editor
+                                    and widget.document().isRedoAvailable())
 
         # Copy, cut, paste, delete
         has_selection = widget.has_selected_text()
@@ -1375,7 +1344,7 @@ class MainWindow(QMainWindow, SpyderConfigurationAccessor):
             child.setEnabled(False)
 
         widget, textedit_properties = self.get_focus_widget_properties()
-        if textedit_properties is None: # widget is not an editor/console
+        if textedit_properties is None:  # widget is not an editor/console
             return
 
         # !!! Below this line, widget is expected to be a QPlainTextEdit
@@ -1517,10 +1486,12 @@ class MainWindow(QMainWindow, SpyderConfigurationAccessor):
                         'executable',
                         section='main_interpreter'
                     )
-                pypath = self.get_conf('spyder_pythonpath', default=None)
+                pypath = self.get_conf('spyder_pythonpath', default=None,
+                                       section='pythonpath_manager')
                 programs.run_python_script_in_terminal(
-                        fname, wdir, args, interact, debug, python_args,
-                        executable, pypath)
+                    fname, wdir, args, interact, debug, python_args,
+                    executable, pypath
+                )
             except NotImplementedError:
                 QMessageBox.critical(self, _("Run"),
                                      _("Running an external system terminal "
@@ -1582,121 +1553,17 @@ class MainWindow(QMainWindow, SpyderConfigurationAccessor):
                 .format(fpath=osp.normpath(fpath), fname=fname)
             )
 
-    # --- Path Manager
-    # ------------------------------------------------------------------------
-    def load_python_path(self):
-        """Load path stored in Spyder configuration folder."""
-        if osp.isfile(self.SPYDER_PATH):
-            with open(self.SPYDER_PATH, 'r', encoding='utf-8') as f:
-                path = f.read().splitlines()
-            self.path = tuple(name for name in path if osp.isdir(name))
-
-        if osp.isfile(self.SPYDER_NOT_ACTIVE_PATH):
-            with open(self.SPYDER_NOT_ACTIVE_PATH, 'r',
-                      encoding='utf-8') as f:
-                not_active_path = f.read().splitlines()
-            self.not_active_path = tuple(name for name in not_active_path
-                                         if osp.isdir(name))
-
-    def save_python_path(self, new_path_dict):
-        """
-        Save path in Spyder configuration folder.
-
-        `new_path_dict` is an OrderedDict that has the new paths as keys and
-        the state as values. The state is `True` for active and `False` for
-        inactive.
-        """
-        path = [p for p in new_path_dict]
-        not_active_path = [p for p in new_path_dict if not new_path_dict[p]]
-        try:
-            encoding.writelines(path, self.SPYDER_PATH)
-            encoding.writelines(not_active_path, self.SPYDER_NOT_ACTIVE_PATH)
-        except EnvironmentError as e:
-            logger.error(str(e))
-        self.set_conf('spyder_pythonpath', self.get_spyder_pythonpath())
-
-    def get_spyder_pythonpath_dict(self):
-        """
-        Return Spyder PYTHONPATH.
-
-        The returned ordered dictionary has the paths as keys and the state
-        as values. The state is `True` for active and `False` for inactive.
-
-        Example:
-            OrderedDict([('/some/path, True), ('/some/other/path, False)])
-        """
-        self.load_python_path()
-
-        path_dict = OrderedDict()
-        for path in self.path:
-            path_dict[path] = path not in self.not_active_path
-
-        for path in self.project_path:
-            path_dict[path] = True
-
-        return path_dict
-
     def get_spyder_pythonpath(self):
         """
-        Return Spyder PYTHONPATH.
+        This is here to provide compatibility for plugins that make use of the
+        Pythonpath managed by Spyder.
+
+        Notes
+        -----
+        This  method is going to be removed in Spyder 6.
         """
-        path_dict = self.get_spyder_pythonpath_dict()
-        path = [k for k, v in path_dict.items() if v]
-        return path
-
-    def update_python_path(self, new_path_dict):
-        """Update python path on Spyder interpreter and kernels."""
-        # Load previous path
-        path_dict = self.get_spyder_pythonpath_dict()
-
-        # Save path
-        if path_dict != new_path_dict:
-            # It doesn't include the project_path
-            self.save_python_path(new_path_dict)
-
-        # Load new path
-        new_path_dict_p = self.get_spyder_pythonpath_dict()  # Includes project
-
-        # Any plugin that needs to do some work based on this signal should
-        # connect to it on plugin registration
-        self.sig_pythonpath_changed.emit(path_dict, new_path_dict_p)
-
-    @Slot()
-    def show_path_manager(self):
-        """Show path manager dialog."""
-        def _dialog_finished(result_code):
-            """Restore path manager dialog instance variable."""
-            self._path_manager = None
-
-        if self._path_manager is None:
-            from spyder.widgets.pathmanager import PathManager
-            projects = self.get_plugin(Plugins.Projects, error=False)
-            read_only_path = ()
-            if projects:
-                read_only_path = tuple(projects.get_pythonpath())
-
-            dialog = PathManager(self, self.path, read_only_path,
-                                 self.not_active_path, sync=True)
-            self._path_manager = dialog
-            dialog.sig_path_changed.connect(self.update_python_path)
-            dialog.redirect_stdio.connect(self.redirect_internalshell_stdio)
-            dialog.finished.connect(_dialog_finished)
-            dialog.show()
-        else:
-            self._path_manager.show()
-            self._path_manager.activateWindow()
-            self._path_manager.raise_()
-            self._path_manager.setFocus()
-
-    def pythonpath_changed(self):
-        """Project's PYTHONPATH contribution has changed."""
-        projects = self.get_plugin(Plugins.Projects, error=False)
-
-        self.project_path = ()
-        if projects:
-            self.project_path = tuple(projects.get_pythonpath())
-        path_dict = self.get_spyder_pythonpath_dict()
-        self.update_python_path(path_dict)
+        ppm = self.get_plugin(Plugins.PythonpathManager)
+        return ppm.get_spyder_pythonpath()
 
     # ---- Preferences
     # -------------------------------------------------------------------------
@@ -1945,7 +1812,7 @@ def main(options, args):
     # **** Create main window ****
     mainwindow = None
     try:
-        if PY3 and options.report_segfault:
+        if options.report_segfault:
             import faulthandler
             with open(faulthandler_file, 'w') as f:
                 faulthandler.enable(file=f)
@@ -1955,11 +1822,13 @@ def main(options, args):
         else:
             mainwindow = create_window(MainWindow, app, splash, options, args)
     except FontError:
-        QMessageBox.information(None, "Spyder",
-                "Spyder was unable to load the <i>Spyder 3</i> "
-                "icon theme. That's why it's going to fallback to the "
-                "theme used in Spyder 2.<br><br>"
-                "For that, please close this window and start Spyder again.")
+        QMessageBox.information(
+            None, "Spyder",
+            "Spyder was unable to load the <i>Spyder 3</i> "
+            "icon theme. That's why it's going to fallback to the "
+            "theme used in Spyder 2.<br><br>"
+            "For that, please close this window and start Spyder again."
+        )
         CONF.set('appearance', 'icon_theme', 'spyder 2')
     if mainwindow is None:
         # An exception occurred
